@@ -103,12 +103,18 @@ SNAPSHOT_SUPPORT = 'snapshot_support'
 CREATE_SHARE_FROM_SNAPSHOT_SUPPORT = 'create_share_from_snapshot_support'
 REVERT_TO_SNAPSHOT_SUPPORT = 'revert_to_snapshot_support'
 MOUNT_SNAPSHOT_SUPPORT = 'mount_snapshot_support'
+CONSISTENT_SNAPSHOT_SUPPORT = 'consistent_snapshot_support'
 
 BOOL_SPECS = (
     SNAPSHOT_SUPPORT,
     CREATE_SHARE_FROM_SNAPSHOT_SUPPORT,
     REVERT_TO_SNAPSHOT_SUPPORT,
-    MOUNT_SNAPSHOT_SUPPORT
+    MOUNT_SNAPSHOT_SUPPORT,
+)
+
+# share group types
+GROUP_BOOL_SPECS = (
+    CONSISTENT_SNAPSHOT_SUPPORT,
 )
 
 REPLICA_GRADUATION_VERSION = '2.56'
