@@ -35,12 +35,14 @@ class FakeShareClient(object):
         self.share_types = mock.Mock()
         self.share_type_access = mock.Mock()
         self.quotas = mock.Mock()
+        self.quota_classes = mock.Mock()
         self.share_snapshots = mock.Mock()
         self.share_snapshot_export_locations = mock.Mock()
         self.share_snapshot_instances = mock.Mock()
         self.share_replicas = mock.Mock()
         self.share_replica_export_locations = mock.Mock()
         self.share_networks = mock.Mock()
+        self.share_network_subnets = mock.Mock()
         self.security_services = mock.Mock()
         self.shares.resource_class = osc_fakes.FakeResource(None, {})
         self.share_instance_export_locations = mock.Mock()
@@ -54,6 +56,8 @@ class FakeShareClient(object):
         self.share_instances = mock.Mock()
         self.pools = mock.Mock()
         self.limits = mock.Mock()
+        self.share_group_types = mock.Mock()
+        self.share_group_type_access = mock.Mock()
 
 
 class ManilaParseException(Exception):
@@ -370,7 +374,7 @@ class FakeShareAccessRule(object):
             'access_level': 'rw',
             'access_to': 'demo',
             'access_type': 'user',
-            'state': 'queued_to_apply',
+            'state': 'active',
             'access_key': None,
             'created_at': datetime.datetime.now().isoformat(),
             'updated_at': None,
@@ -825,7 +829,7 @@ class FakeShareAvailabilityZones(object):
         :param Dictionary attrs:
             A dictionary with all attributes
         :param Integer count:
-            The number of share types to be faked
+            The number of availability zones to be faked
         :return:
             A list of FakeResource objects
         """
@@ -1083,6 +1087,7 @@ class FakeShareNetwork(object):
             A dictionary with all attributes
         :param Integer count:
             The number of share networks to be faked
+
         :return:
             A list of FakeResource objects
         """
@@ -1095,6 +1100,64 @@ class FakeShareNetwork(object):
         return share_networks
 
 
+class FakeShareNetworkSubnet(object):
+    """Fake a share network subnet"""
+
+    @staticmethod
+    def create_one_share_subnet(attrs=None):
+        """Create a fake share network subnet
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+
+        share_network_subnet = {
+            "availability_zone": None,
+            "cidr": "10.0.0.0/24",
+            "created_at": datetime.datetime.now().isoformat(),
+            "gateway": "10.0.0.1",
+            'id': str(uuid.uuid4()),
+            "ip_version": 4,
+            "mtu": "1500",
+            "network_type": "vlan",
+            "neutron_net_id": str(uuid.uuid4()),
+            "neutron_subnet_id": str(uuid.uuid4()),
+            "segmentation_id": 1010,
+            "share_network_id": str(uuid.uuid4()),
+            "share_network_name": str(uuid.uuid4()),
+            "updated_at": datetime.datetime.now().isoformat(),
+        }
+
+        share_network_subnet.update(attrs)
+        share_network_subnet = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_network_subnet),
+            loaded=True)
+        return share_network_subnet
+
+    @staticmethod
+    def create_share_network_subnets(attrs=None, count=2):
+        """Create multiple fake share network subnets.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share network subnets to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_network_subnets = []
+        for n in range(count):
+            share_network_subnets.append(
+                FakeShareNetworkSubnet.create_one_share_subnet(attrs))
+
+        return share_network_subnets
+
+
 class FakeShareGroup(object):
     """Fake a share group"""
 
@@ -1152,3 +1215,78 @@ class FakeShareGroup(object):
             share_groups.append(
                 FakeShareGroup.create_one_share_group(attrs))
         return share_groups
+
+
+class FakeShareGroupType(object):
+    """Fake one or more share group types"""
+
+    @staticmethod
+    def create_one_share_group_type(attrs=None, methods=None):
+        """Create a fake share group type
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+
+        share_group_type_info = {
+            "is_public": True,
+            "group_specs": {
+                "snapshot_support": True
+            },
+            "share_types": ['share-types-id-' + uuid.uuid4().hex],
+            "id": 'share-group-type-id-' + uuid.uuid4().hex,
+            "name": 'share-group-type-name-' + uuid.uuid4().hex,
+            "is_default": False
+        }
+
+        share_group_type_info.update(attrs)
+        share_group_type = osc_fakes.FakeResource(info=copy.deepcopy(
+                                                  share_group_type_info),
+                                                  methods=methods,
+                                                  loaded=True)
+        return share_group_type
+
+    @staticmethod
+    def create_share_group_types(attrs=None, count=2):
+        """Create multiple fake share group types.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share group types to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_group_types = []
+        for n in range(0, count):
+            share_group_types.append(
+                FakeShareGroupType.create_one_share_group_type(attrs))
+
+        return share_group_types
+
+    @staticmethod
+    def get_share_group_types(share_group_types=None, count=2):
+        """Get an iterable MagicMock object with a list of faked group types.
+
+        If types list is provided, then initialize the Mock object with the
+        list. Otherwise create one.
+
+        :param List types:
+            A list of FakeResource objects faking types
+        :param Integer count:
+            The number of group types to be faked
+        :return
+            An iterable Mock object with side_effect set to a list of faked
+            group types
+        """
+
+        if share_group_types is None:
+            share_group_types = FakeShareGroupType.share_group_types(count)
+
+        return mock.Mock(side_effect=share_group_types)
