@@ -15,6 +15,8 @@ from unittest import mock
 from osc_lib import exceptions
 from osc_lib import utils as oscutils
 
+from manilaclient import api_versions
+from manilaclient.api_versions import MAX_VERSION
 from manilaclient.common import cliutils
 
 from manilaclient.osc import utils
@@ -34,6 +36,8 @@ class TestShareReplica(manila_fakes.TestShare):
 
         self.replicas_mock = self.app.client_manager.share.share_replicas
         self.replicas_mock.reset_mock()
+        self.app.client_manager.share.api_version = api_versions.APIVersion(
+            MAX_VERSION)
 
         self.replica_el_mock = (
             self.app.client_manager
@@ -84,7 +88,7 @@ class TestShareReplicaCreate(TestShareReplica):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.replicas_mock.create.assert_called_with(
-            self.share,
+            share=self.share,
             availability_zone=None
         )
 
@@ -106,13 +110,75 @@ class TestShareReplicaCreate(TestShareReplica):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.replicas_mock.create.assert_called_with(
-            self.share,
+            share=self.share,
             availability_zone=self.share.availability_zone
         )
 
         self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
+    def test_share_replica_create_scheduler_hint_valid(self):
+        arglist = [
+            self.share.id,
+            '--availability-zone', self.share.availability_zone,
+            '--scheduler-hint', ('only_host=host1@backend1#pool1'),
+        ]
+        verifylist = [
+            ('share', self.share.id),
+            ('availability_zone', self.share.availability_zone),
+            ('scheduler_hint', {'only_host': 'host1@backend1#pool1'})
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.replicas_mock.create.assert_called_with(
+            share=self.share,
+            availability_zone=self.share.availability_zone,
+            scheduler_hints={'only_host': 'host1@backend1#pool1'}
+        )
+
+        self.assertCountEqual(self.columns, columns)
+        self.assertCountEqual(self.data, data)
+
+    def test_share_replica_create_scheduler_hint_invalid_hint(self):
+        arglist = [
+            self.share.id,
+            '--availability-zone', self.share.availability_zone,
+            '--scheduler-hint', 'fake_hint=host1@backend1#pool1'
+        ]
+        verifylist = [
+            ('share', self.share.id),
+            ('availability_zone', self.share.availability_zone),
+            ('scheduler_hint', {'fake_hint': 'host1@backend1#pool1'})
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(exceptions.CommandError,
+                          self.cmd.take_action,
+                          parsed_args)
+
+    def test_share_replica_create_scheduler_hint_invalid_version(self):
+        self.app.client_manager.share.api_version = api_versions.APIVersion(
+            "2.66")
+
+        arglist = [
+            self.share.id,
+            '--availability-zone', self.share.availability_zone,
+            '--scheduler-hint', 'only_host=host1@backend1#pool1'
+        ]
+        verifylist = [
+            ('share', self.share.id),
+            ('availability_zone', self.share.availability_zone),
+            ('scheduler_hint', {'only_host': 'host1@backend1#pool1'})
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(exceptions.CommandError,
+                          self.cmd.take_action,
+                          parsed_args)
+
     def test_share_replica_create_wait(self):
         arglist = [
             self.share.id,
@@ -128,7 +194,7 @@ class TestShareReplicaCreate(TestShareReplica):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.replicas_mock.create.assert_called_with(
-            self.share,
+            share=self.share,
             availability_zone=None
         )
 
@@ -153,7 +219,7 @@ class TestShareReplicaCreate(TestShareReplica):
             columns, data = self.cmd.take_action(parsed_args)
 
             self.replicas_mock.create.assert_called_with(
-                self.share,
+                share=self.share,
                 availability_zone=None
             )
 
