@@ -15,7 +15,7 @@
 
 from manilaclient import api_versions
 from manilaclient import base
-from manilaclient.common.apiclient import base as common_base
+from manilaclient.common import constants
 
 RESOURCES_PATH = '/share-replicas'
 RESOURCE_PATH = '/share-replicas/%s'
@@ -24,7 +24,7 @@ RESOURCES_NAME = 'share_replicas'
 RESOURCE_NAME = 'share_replica'
 
 
-class ShareReplica(common_base.Resource):
+class ShareReplica(base.Resource):
     """A replica is 'mirror' instance of a share at some point in time."""
     def __repr__(self):
         return "<Share Replica: %s>" % self.id
@@ -50,20 +50,34 @@ class ShareReplicaManager(base.ManagerWithFind):
     """Manage :class:`ShareReplica` resources."""
     resource_class = ShareReplica
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def get(self, replica):
+        return self._get_share_replica(replica)
+
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION)  # noqa
+    def get(self, replica):  # noqa F811
+        return self._get_share_replica(replica)
+
+    def _get_share_replica(self, replica):
         """Get a share replica.
 
         :param replica: either replica object or its UUID.
         :rtype: :class:`ShareReplica`
         """
-        replica_id = common_base.getid(replica)
+        replica_id = base.getid(replica)
         return self._get(RESOURCE_PATH % replica_id, RESOURCE_NAME)
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def list(self, share=None, search_opts=None):
+        return self._list_share_replicas(share=share, search_opts=search_opts)
+
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION)  # noqa
+    def list(self, share=None, search_opts=None):  # noqa F811
+        return self._list_share_replicas(share=share, search_opts=search_opts)
+
+    def _list_share_replicas(self, share=None, search_opts=None):
         """List all share replicas or list replicas belonging to a share.
 
         :param share: either share object or its UUID.
@@ -72,13 +86,13 @@ class ShareReplicaManager(base.ManagerWithFind):
         """
 
         if share:
-            share_id = '?share_id=' + common_base.getid(share)
+            share_id = '?share_id=' + base.getid(share)
             url = RESOURCES_PATH + '/detail' + share_id
             return self._list(url, RESOURCES_NAME)
         else:
             return self._list(RESOURCES_PATH + '/detail', RESOURCES_NAME)
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def promote(self, replica):
         """Promote the provided replica.
@@ -87,27 +101,55 @@ class ShareReplicaManager(base.ManagerWithFind):
         """
         return self._action('promote', replica)
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION)  # noqa
+    def promote(self, replica):  # noqa F811
+        """Promote the provided replica.
+
+        :param replica: either replica object or its UUID.
+        """
+        return self._action('promote', replica)
+
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def create(self, share, availability_zone=None):
+        return self._create_share_replica(
+            share, availability_zone=availability_zone)
+
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION, '2.66')  # noqa
+    def create(self, share, availability_zone=None):  # noqa F811
+        return self._create_share_replica(
+            share, availability_zone=availability_zone)
+
+    @api_versions.wraps("2.67")  # noqa
+    def create(self, share, availability_zone=None, scheduler_hints=None): # noqa F811
+        return self._create_share_replica(
+            share, availability_zone=availability_zone,
+            scheduler_hints=scheduler_hints)
+
+    def _create_share_replica(self, share, availability_zone=None,
+                              scheduler_hints=None):
         """Create a replica for a share.
 
         :param share: The share to create the replica of. Can be the share
         object or its UUID.
         :param availability_zone: The 'availability_zone' object or its UUID.
+        :param scheduler_hints: The scheduler_hints as key=value pair. Only
+        supported key is 'only_host'.
         """
 
-        share_id = common_base.getid(share)
+        share_id = base.getid(share)
         body = {'share_id': share_id}
 
         if availability_zone:
-            body['availability_zone'] = common_base.getid(availability_zone)
+            body['availability_zone'] = base.getid(availability_zone)
 
+        if scheduler_hints:
+            body['scheduler_hints'] = scheduler_hints
         return self._create(RESOURCES_PATH,
                             {RESOURCE_NAME: body},
                             RESOURCE_NAME)
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def delete(self, replica, force=False):
         """Delete a replica.
@@ -117,7 +159,16 @@ class ShareReplicaManager(base.ManagerWithFind):
         """
         self._do_delete(replica, force=force)
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION)  # noqa
+    def delete(self, replica, force=False):  # noqa F811
+        """Delete a replica.
+
+        :param replica: either replica object or its UUID.
+        :param force: optional 'force' flag.
+        """
+        self._do_delete(replica, force=force)
+
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def reset_state(self, replica, state):
         """Reset the 'status' attr of the replica.
@@ -127,7 +178,16 @@ class ShareReplicaManager(base.ManagerWithFind):
         """
         return self._do_reset_state(replica, state, "reset_status")
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION)  # noqa
+    def reset_state(self, replica, state):  # noqa F811
+        """Reset the 'status' attr of the replica.
+
+        :param replica: either replica object or its UUID.
+        :param state: state to set the replica's 'status' attr to.
+        """
+        return self._do_reset_state(replica, state, "reset_status")
+
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def reset_replica_state(self, replica, state):
         """Reset the 'replica_state' attr of the replica.
@@ -137,7 +197,16 @@ class ShareReplicaManager(base.ManagerWithFind):
         """
         return self._do_reset_state(replica, state, "reset_replica_state")
 
-    @api_versions.wraps("2.11")
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION)  # noqa
+    def reset_replica_state(self, replica, state):  # noqa F811
+        """Reset the 'replica_state' attr of the replica.
+
+        :param replica: either replica object or its UUID.
+        :param state: state to set the replica's 'replica_state' attr to.
+        """
+        return self._do_reset_state(replica, state, "reset_replica_state")
+
+    @api_versions.wraps("2.11", constants.REPLICA_PRE_GRADUATION_VERSION)
     @api_versions.experimental_api
     def resync(self, replica):
         """Re-sync the provided replica.
@@ -146,6 +215,14 @@ class ShareReplicaManager(base.ManagerWithFind):
         """
         return self._action('resync', replica)
 
+    @api_versions.wraps(constants.REPLICA_GRADUATION_VERSION)  # noqa
+    def resync(self, replica):  # noqa F811
+        """Re-sync the provided replica.
+
+        :param replica: either replica object or its UUID.
+        """
+        return self._action('resync', replica)
+
     def _action(self, action, replica, info=None, **kwargs):
         """Perform a share replica 'action'.
 
@@ -156,7 +233,7 @@ class ShareReplicaManager(base.ManagerWithFind):
         """
         body = {action: info}
         self.run_hooks('modify_body_for_action', body, **kwargs)
-        replica_id = common_base.getid(replica)
+        replica_id = base.getid(replica)
         url = RESOURCE_PATH_ACTION % replica_id
         return self.api.client.post(url, body=body)
 
@@ -165,7 +242,7 @@ class ShareReplicaManager(base.ManagerWithFind):
 
         :param replica: either share replica object or its UUID.
         """
-        replica_id = common_base.getid(replica)
+        replica_id = base.getid(replica)
         url = RESOURCE_PATH % replica_id
 
         if force:
@@ -178,7 +255,7 @@ class ShareReplicaManager(base.ManagerWithFind):
 
         :param replica: either share replica object or its UUID.
         """
-        return self._action(action_name, common_base.getid(replica))
+        return self._action(action_name, base.getid(replica))
 
     def _do_reset_state(self, replica, state, action_name):
         """Update the provided share replica with the provided state.
